function [SS] = complete(G, beta, D)
% Complete Netsleuth algorithm
%   Returns a seed set SS which is of size (1, length(G)) basically an indicator for who the seeds are. 
% G is the graph as an adjacency matrix
% beta is the infectivity parameter in the SI process
% D is the set of infected nodes in the final time step.

% graph may be disconnected

nnodes = length(D);
infectedNodes = find(D);



infectedSubgraph = G(infectedNodes, infectedNodes);
[M N] = graphconncomp(sparse(infectedSubgraph));

sample_curr = zeros(M, nnodes);
C_curr = zeros(M, nnodes);
% Divide the graph into disconnected components
maxcomp = -1;
value = 0;
for i = 1:M
    subgraphInfectedNodes = infectedNodes(find(N == i));
    if length(find(N == 1)) > value
        % For finding the maximum component
        maxcomp = i;
        value = length(find(N == 1));
    end
    sample_curr(i, subgraphInfectedNodes) =  1;
%    for node = subgraphInfectedNodes
%        if find(infectedNodes == node)
%            sample_curr(i, node) = 1;
%        end
%    end
end

S = zeros(M, nnodes);
X = -1*ones(M, nnodes);
for i = 1:M
    infected =  find(sample_curr(i, :));

    mdl0 = Inf;
    mdl1 = 0;
    j = 1;
    while(mdl1 < mdl0)
        if ~isempty(infected)
            seed = Netsleuth(infected, G, beta);
            X(i,j) = seed;
            j = j + 1;
            S(i, seed) = 1;
            mdl1 = MDL(G, sample_curr(i,:), S(i,:), beta);
            if mdl1 < mdl0
                mdl0 = mdl1;
                mdl1 = 0;
                infected = setdiff(infected, seed);
            else
                X(i,j -1) = -1;
                S(i, seed) = 0;
                break;
            end
        else
            break;
        end
        
    end
    
    
end
if M > 1
    SS = sum(S);
else
    SS = S;
end

end
